@@ -94,7 +94,7 @@ class CardWithIdTest(unittest.TestCase):
     card.card_id = 'vizzini'
     card.header = header
     card.add_section(section)
-    output = card.card.render()
+    output = card.card().render()
     print(output)
 
     self.assertDictEqual(
